@@ -5,7 +5,7 @@ from .clinic.list_modules import load_stdlib_sitepackages, load_user_modules, \
     ModulesFinder
 
 
-def pack(searchpath, stdlib_searchpath, outdir, filename):
+def pack(searchpath, stdlib_searchpath, outdir, filename, excludes=None):
     print(
         'Create brython_modules.js with all the modules used by the '
         'application'
@@ -17,10 +17,11 @@ def pack(searchpath, stdlib_searchpath, outdir, filename):
     )
 
     print('Finding packages...')
-    user_modules = load_user_modules(searchpath)
+    user_modules = load_user_modules(searchpath, excludes)
     finder = ModulesFinder(
         stdlib=stdlib,
-        user_modules=user_modules
+        user_modules=user_modules,
+        excludes=excludes
     )
     finder.inspect()
     outfilename = path.join(outdir, filename)
